@@ -1,9 +1,10 @@
 from abc import ABC, abstractmethod
 from concurrent import futures as ft
+from dask.distributed import Client
 
 class Engine(ABC):
     @abstractmethod
-    def __tapr_engine__map__(self, func, *args):
+    def __tapr_engine_map__(self, func, *args):
         pass
 
 class ProcessEngine(Engine):
@@ -14,7 +15,7 @@ class ProcessEngine(Engine):
     def processes(self):
         return self._processes
 
-    def __tapr_engine__map__(self, func, *args):
+    def __tapr_engine_map__(self, func, *args):
         with ft.ProcessPoolExecutor(self._processes) as ex:
             return list(ex.map(func, *args))
 
@@ -33,7 +34,7 @@ class ThreadEngine(Engine):
     def threads(self):
         return self._threads
 
-    def __tapr_engine__map__(self, func, *args):
+    def __tapr_engine_map__(self, func, *args):
         with ft.ThreadPoolExecutor(self._threads) as ex:
             return list(ex.map(func, *args))
 
@@ -48,7 +49,7 @@ class StandardEngine(Engine):
     def __init__(self):
         pass
 
-    def __tapr_engine__map__(self, func, *args):
+    def __tapr_engine_map__(self, func, *args):
         return list(map(func, *args))
 
     def __str__(self):
@@ -56,3 +57,23 @@ class StandardEngine(Engine):
 
     def __repr__(self):
         return str(self)
+
+
+class DaskClientEngine(Engine):
+    def __init__(self, *client_args, **client_kwargs):
+        self._client = Client(*client_args, **client_kwargs)
+
+    @property
+    def client(self):
+        return self._client
+
+    def __tapr_engine_map__(self, func, *args):
+        args = [list(arg) for arg in args]
+        futures = self._client.map(func, *args)
+        return self._client.gather(futures)
+
+    def __str__(self):
+        return f"Dask Client Engine"
+
+    def __repr__(self):
+        return str(self)
\ No newline at end of file
